package static

import (
	"context"
	"flag"
	"time"

	"github.com/open-io/oio-exporter/common"
	"github.com/open-io/oio-exporter/daemon"
)

var confInterval = time.Duration(0)

func InitFlags(fs *flag.FlagSet) {
	fs.DurationVar(&confInterval, "static.interval", confInterval, "[static] interval between polls")
}

var Factory = &staticDaemonFactory{}

type staticDaemonFactory struct{}

func (df *staticDaemonFactory) Daemons(inventory *common.Inventory) map[string]interface{} {
	return map[string]interface{}{
		"static": &staticDaemonParams{
			Namespace: inventory.Namespace,
			Localname: inventory.Localname,
			Rack:      inventory.Rack,
		},
	}
}

func (df *staticDaemonFactory) New(paramsI interface{}) daemon.DaemonI {
	params := paramsI.(*staticDaemonParams)

	return &staticDaemon{
		namespace: params.Namespace,
		localname: params.Localname,
		rack:      params.Rack,
	}
}

type staticDaemonParams struct {
	Namespace string
	Localname string
	Rack      string
}

type staticDaemon struct {
	daemon.BaseDaemon

	namespace string
	localname string
	rack      string
}

func (d *staticDaemon) Interval() time.Duration {
	return confInterval
}

func (d *staticDaemon) Collect(ctx context.Context, m *common.MetricData) error {
	m.Set(&common.Metric{
		Name: "static_host",
		Labels: [][]string{
			[]string{"namespace", d.namespace},
			[]string{"localname", d.localname},
			[]string{"rack", d.rack},
		},
		Value: float64(time.Now().Unix()),
	})

	return nil
}
